#!/bin/bash

#
# packager         : sebastian <zenwalkuser> seb@seb2.dyndns.org
#
# source location  :  http://www.fftw.org/fftw-2.1.5.tar.gz
#
# 
#
#
# last revised     : 23/2/2007
#
#

_error() {
  echo -e $1
  echo -e "\nSee $soft-install.log for errors"
  exit 1
}

soft='fftw_legacy'
softversion='2.1.5'
packageversion='44.3'

arch='i486'
cpu='i686'
makeopts='-j2'

buildir=$(pwd)
srcpkg="$buildir/$soft-$softversion.tar.gz"
src="$buildir/$soft-$softversion"
srcuri="http://www.fftw.org/fftw-2.1.5.tar.gz"
package="$soft-$softversion-$arch-$packageversion"
dest="$buildir/$package"

echo "------------------------------------------------"
echo "Build package: $soft $softversion"
echo "------------------------------------------------"

cd $buildir
rm -rf $src
if [ ! -f $srcpkg ]; then
  echo "- Download source..."
  wget --passive --quiet $srcuri || _error "\tDownload failed!"
fi 
echo "- Unpacking source..."
tar -xzf $srcpkg
rm -f $dest.tgz
rm -rf $dest
mkdir -p $dest
chown -R root:root .
export CFLAGS="-O2 -march=$arch -mtune=$cpu"
export CXXFLAGS=$CFLAGS

echo "- Configuring package..."
cd $src
    ./configure --prefix=/usr \
    --sysconfdir=/etc \
    --localstatedir=/var > ../$soft-install.log

echo "- Compiling package..."
make $makeopts >> ../$soft-install.log 2>&1 || _error "\tCompile failed"
echo "- Install package from temp directory"
make install DESTDIR=$dest >> ../$soft-install.log

echo "- Stripped all binaries and gzipping man pages..."
( cd $dest
  find . | xargs file | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded
)
( cd $dest/usr/info
  find . -name "*.info*" | xargs gzip -9
)

echo "- Copying documentation..."
mkdir -p $dest/usr/doc/$soft-$softversion
cp -af \
  AUTHORS COPYING INSTALL NEWS README ChangeLog $dest/usr/doc/$soft-$softversion

mkdir -p $dest/install
cat > $dest/install/slack-desc <<END
   |-----handy-ruler------------------------------------------------------|
$soft: fftw - a library for computing DFT
$soft:
$soft: 
$soft: FFTW is a C subroutine library for computing the discrete Fourier
$soft: transform (DFT) in one or more dimensions, of arbitrary input size
$soft: and of both real and complex data
$soft:  
$soft: This is the legacy version 2 series
$soft: 
$soft:
$soft: Build for Zenwalk
END

mkdir -p $dest/usr/src/$soft-$softversion
( cd $buildir
cp -a build-$soft.sh $dest/usr/src/$soft-$softversion/
)

#
# update the dynamic libraries
#
cat << "EOF" > $dest/install/doinst.sh
/sbin/ldconfig
EOF


cd $dest

# creating package
echo "- Creating $soft package..."
makepkg -l y -c y $dest.tgz > /dev/null 2>&1

cd $buildir
md5sum $package.tgz > $dest.md5

echo "- Deleting temporary directory's..."
rm -rf $src
rm -rf $dest

echo "Package created complete."
exit 0
